@@ -71,7 +71,7 @@ class TestOvnNorthMappers(object):
         row = OvnSubnetRow(SUBNET_ID102, cidr=SUBNET_CIDR, external_ids={
             SubnetMapper.OVN_NETWORK_ID: NETWORK_ID1,
             SubnetMapper.OVN_IP_VERSION: '6'
-        })
+        }, ip_version=6)
         subnet = SubnetMapper.row2rest(row)
         assert_subnet_equal(subnet, row)
 
@@ -220,10 +220,10 @@ class TestOvnNorthMappers(object):
         NetworkMapper._boolean_or_exception('', False)
         with pytest.raises(RestDataError) as expected_exception:
             NetworkMapper._boolean_or_exception('attr1', 'boloni')
-        assert expected_exception.value.message == 'attr1 must be of type bool'
+        assert str(expected_exception.value) == 'attr1 must be of type bool'
         with pytest.raises(RestDataError) as expected_exception:
             NetworkMapper._boolean_or_exception('attr2', [])
-        assert expected_exception.value.message == 'attr2 must be of type bool'
+        assert str(expected_exception.value) == 'attr2 must be of type bool'
 
     def test_acl_to_rest_minimal(self):
         name = 'sec1'
